@@ -1,12 +1,12 @@
-from . import time
+from . import hash, ip, time
 from .config import Config
 from .email import Email
 from .env import APP_ENV
 from .group_robot import GroupRobot
 from .logger import Logger
+from .redis import Redis, RedisLock
 from .response import BaseResponse, ErrorResponse, SuccessResponse
-
-__version__ = "2024.1.8.2"
+from .version import Version
 
 __all__ = [
     "APP_ENV",
@@ -16,7 +16,11 @@ __all__ = [
     "ErrorResponse",
     "GroupRobot",
     "Logger",
+    "Redis",
+    "RedisLock",
     "SuccessResponse",
-    "VERSION",
+    "Version",
+    "hash",
+    "ip",
     "time",
 ]
